@@ -63,7 +63,7 @@
 
 #![cfg_attr(not(feature = "std"), no_std)]
 
-use core::fmt::Debug;
+use core::{fmt::Debug, iter::FilterMap};
 
 #[derive(Debug, Copy, Clone, Ord, PartialOrd, Eq, PartialEq, Hash)]
 #[must_use]
@@ -236,7 +236,7 @@ impl<T, E> From<Option<T>> for NullableResult<T, E> {
 #[macro_export]
 macro_rules! extract {
     ($nr:expr) => {{
-        let nr = $nr;
+        let nr = NullableResult::from($nr);
         match nr {
             nullable_result::NullableResult::Ok(item) => item,
             nullable_result::NullableResult::Err(err) => {
@@ -248,3 +248,17 @@ macro_rules! extract {
         }
     }};
 }
+
+pub trait IterExt<T, E>: Iterator<Item = NullableResult<T, E>>
+where
+    Self: Sized,
+{
+    fn filter_nulls(self) -> FilterNulls<Self, T, E> {
+        self.filter_map(Option::from)
+    }
+}
+
+impl<I, T, E> IterExt<T, E> for I where I: Iterator<Item = NullableResult<T, E>> {}
+
+type FilterNulls<I, T, E> =
+    FilterMap<I, fn(NullableResult<T, E>) -> Option<Result<T, E>>>;
